@@ -127,8 +127,7 @@ for my $file ( @headers ) {
         }
         elsif ( $line =~ m|^typedef (\w+(?:\s*\*)?) \(GLAPIENTRY \* PFN(\w+)PROC\)\s*\((.*)\);| ) {
             my ( $restype, $name, $sig ) = ( $1, $2, $3 );
-            my $s =
-              { signature => $sig, restype => $restype, feature => $feature_name, name => $name, glewtype => 'fun' };
+            my $s = { signature => $sig, restype => $restype, feature => $feature_name, name => $name };
             $signature{$name} = $s;
             push @{ $features{$feature_name} }, $s;
 
@@ -138,8 +137,7 @@ for my $file ( @headers ) {
 
             # Some external function, likely imported from libopengl / opengl32
             my ( $restype, $name, $sig ) = ( $1, $2, $3 );
-            my $s =
-              { signature => $sig, restype => $restype, feature => $feature_name, name => $name, glewtype => 'fun' };
+            my $s = { signature => $sig, restype => $restype, feature => $feature_name, name => $name };
             $signature{ uc $name } = $s;
             $case_map{ uc $name }  = $name;
             push @{ $features{$feature_name} }, $s;
@@ -156,22 +154,6 @@ for my $file ( @headers ) {
             my ( $name, $impl ) = ( $1, $2 );
             $alias{$impl} = $name;
 
-            # #define GLEW_VERSION_1_1 GLEW_GET_VAR(__GLEW_VERSION_1_1)
-        }
-        elsif ( $line =~ m|^#define (\w+) GLEW_GET_VAR\(__(\w+)\)| ) {
-            my ( $name, $impl ) = ( $1, $2 );
-            $alias{$impl} = $name;
-
-            # GLEW_VAR_EXPORT GLboolean __GLEW_VERSION_1_1;
-        }
-        elsif ( $line =~ m|^GLEW_VAR_EXPORT (\w+) __(\w+)| ) {
-            my ( $restype, $impl ) = ( $1, $2 );
-            my $s = { signature => 'void', restype => $restype, feature => $feature_name, glewtype => 'var' };
-            my $name = $alias{$impl};
-            $signature{$name} = $s;
-            push @{ $features{$feature_name} }, $s;
-            $case_map{$name} = $impl;
-
         }
     }
 }
@@ -308,10 +290,9 @@ CODE:
     if ( ! _done_glewInit ) {
         glewExperimental = GL_TRUE;
         glewInit();
-        _done_glewInit++;
     }
 XS
-        if ( $item->{glewtype} eq 'fun' and $glewImpl ) {
+        if ( $glewImpl ) {
             $res .= <<XS;
     if ( ! $glewImpl ) {
         croak("$name not available on this machine");
@@ -327,8 +308,8 @@ XS
 
         }
         else {
-            $res .= "    RETVAL = $name" . ( ( $item->{glewtype} eq 'var' ) ? ";\n" : "($args);\n" );
             $res .= <<XS;
+    RETVAL = $name($args);
 OUTPUT:
     RETVAL
 
